@@ -6,7 +6,6 @@
 
 #include "line.h"
 #include "lineutil_p.h"
-#include "location.h"
 #include "datatypes_p.h"
 #include "json_p.h"
 #include "mergeutil_p.h"
@@ -67,11 +66,6 @@ bool Line::hasTextColor() const
     return d->textColor.isValid();
 }
 
-void Line::setMetaData(const LineMetaData &metaData)
-{
-    d->metaData = metaData;
-}
-
 QString Line::logo() const
 {
     return AssetRepository::localFile(d->metaData.logoUrl());
@@ -127,7 +121,7 @@ Line Line::merge(const Line &lhs, const Line &rhs)
     l.setModeString(MergeUtil::mergeString(lhs.modeString(), rhs.modeString()));
     l.setName(MergeUtil::mergeString(lhs.name(), rhs.name()));
     if (l.name().startsWith(l.modeString(), Qt::CaseInsensitive)) {
-        l.setName(l.name().midRef(l.modeString().size()).trimmed().toString());
+        l.setName(QStringView(l.name()).mid(l.modeString().size()).trimmed().toString());
     }
 
     l.setColor(mergeColor(lhs.color(), rhs.color()));
@@ -140,6 +134,20 @@ Line Line::merge(const Line &lhs, const Line &rhs)
     return l;
 }
 
+void Line::applyMetaData(const Location &location, bool download)
+{
+    if (name().isEmpty() || !location.hasCoordinate()) {
+        return;
+    }
+
+    d->metaData = LineMetaData::find(location.latitude(), location.longitude(), name(), mode());
+
+    if (download && AssetRepository::instance()) {
+        AssetRepository::instance()->download(d->metaData.logoUrl());
+        AssetRepository::instance()->download(d->metaData.modeLogoUrl());
+    }
+}
+
 QJsonObject Line::toJson(const Line &l)
 {
     auto obj = Json::toJson(l);
