@@ -21,8 +21,6 @@ namespace LineUtil
     bool isSameLineNameStrict(const QString &lhs, const QString &rhs);
     bool isSameLineNameFuzzy(const QString &lhs, const QString &rhs);
     bool isCompatibleMode(Line::Mode lhs, Line::Mode rhs);
-    void applyMetaData(Line &line, const Location &loc, bool download);
-    KPUBLICTRANSPORT_EXPORT void setMetaData(Line &line, LineMetaData metaData);
 }
 
 }
